@@ -99,7 +99,7 @@ module SiSU_Concordance
           SiSU_Concordance::Source::Words.new(@particulars).songsheet
         end
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -216,7 +216,7 @@ WOK
           @alphlst=SiSU_i18n::Alphabet.new(@md.opt.lng).hash_strings
           @rgx_scanlist=%r{#{Mx[:fa_italics_o]}[#{@alphlst[:l]}#{@alphlst[:u]}0-9"\s]{2,12}#{Mx[:fa_italics_c]}|#{Mx[:fa_bold_o]}[#{@alphlst[:l]}#{@alphlst[:u]}0-9"\s]{2,12}#{Mx[:fa_bold_c]}|(?:https?|file)://\S+|<\S+?>|[#{@alphlst[:l]}#{@alphlst[:u]}]+|\w+}mi
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -227,7 +227,7 @@ WOK
           @file_concordance=File.open(@file.place_file.html_concordance.dir,'w')
           map_para
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
@@ -239,15 +239,14 @@ WOK
         %{<a href="doc#{@md.lang_code_insert}#{Sfx[:html]}\##{wordlocation}">#{wordlocation}</a>;  }
       end
       def location_seg(wordlocation,show) ##fix
-        @word_location_seg=wordlocation.gsub(/(.+?)\#(\d+)/,"\\1#{@md.lang_code_insert}#{Sfx[:html]}#\\2") unless wordlocation.nil?
-        case wordlocation
-        when @rxp_t1
-          %{[<a href="doc#{@md.lang_code_insert}#{Sfx[:html]}##{show}">H</a>]#{show},  }
-        when @rxp_t2
-          %{[<a href="doc#{@md.lang_code_insert}#{Sfx[:html]}##{show}">H</a>]#{show},  }
-        when @rxp_t3
-          %{[<a href="doc#{@md.lang_code_insert}#{Sfx[:html]}##{show}">H</a>]#{show},  }
-        else %{<a href="#{@word_location_seg}">#{show}</a>,  }
+        unless wordlocation.nil?
+          wl=wordlocation.gsub(/(.+?)\#(\d+)/,"\\1#{@md.lang_code_insert}#{Sfx[:html]}#\\2")
+          case wordlocation
+          when /#{@rxp_t1}|@rxp_t2}|#{@rxp_t3}/
+            %{[<a href="doc#{@md.lang_code_insert}#{Sfx[:html]}##{show}">H</a>]#{show},  }
+          when /(.+?)\#(\d+)/
+             %{<a href="#{wl}">#{show}</a>,  }
+          end
         end
       end
       def map_para
@@ -316,10 +315,11 @@ WOK
                     end
                     @freq[word] +=1
                     @word_map[word] ||= []
-                    if line !~@rxp_lv1 \
-                    and line !~@rxp_lv2 \
-                    and line !~@rxp_lv3 #fix @rxp_lv #  Mx[:lv_o]
-                      @word_map[word] << location_seg("#{@seg}\##{ocn}",ocn)
+                    if line !~ /#{@rxp_lv1}|#{@rxp_lv2}|#{@rxp_lv3}/
+                      loc_=%{#{location_seg("#{@seg}\##{ocn}",ocn).to_s}}
+                      unless loc_.empty?
+                        @word_map[word] << loc_
+                      end
                     else
                       @word_map[word] << case line
                       when @rxp_lv1; location_seg('T1',ocn) #fix @rxp_lv #  Mx[:lv_o]
