@@ -78,7 +78,7 @@ module SiSU_DAL
   require_relative 'dal_images'                         # dal_images.rb
   require_relative 'dal_metadata'                       # dal_metadata.rb
   require_relative 'dal_character_check'                # dal_character_check.rb
-  require_relative 'dal_substitutions_and_insertions'   # dal_substitutions_and_insertions.rb
+  require_relative 'dal_misc_arrange'                   # dal_misc_arrange.rb
   require_relative 'dal_expand_insertions'              # dal_expand_insertions.rb
   require_relative 'prog_text_translation'              # prog_text_translation.rb
   require_relative 'shared_sem'                         # shared_sem.rb
@@ -123,7 +123,7 @@ module SiSU_DAL
         : @opt.fns
         create_dal
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@@fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@@fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -144,7 +144,7 @@ module SiSU_DAL
         ? read_fnc
         : @@dal_array.dup
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -163,7 +163,7 @@ module SiSU_DAL
         end
         dal=(@@idx_arr[:sst].empty?) ? read_idx_sst : @@idx_arr[:sst].dup #check
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -182,7 +182,7 @@ module SiSU_DAL
         end
         dal=(@@idx_arr[:tex].empty?) ? read_idx_raw : @@idx_arr[:tex].dup #check
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -201,7 +201,7 @@ module SiSU_DAL
         end
         dal=(@@idx_arr[:html].empty?) ? read_idx_html : @@idx_arr[:html].dup
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -220,7 +220,7 @@ module SiSU_DAL
         end
         dal=(@@idx_arr[:xhtml].empty?) ? read_idx_xhtml : @@idx_arr[:xhtml].dup
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -239,7 +239,7 @@ module SiSU_DAL
         end
         dal=(@@map_arr[:nametags].empty?) ? read_map_nametags : @@map_arr[:nametags].dup
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -258,7 +258,7 @@ module SiSU_DAL
         end
         dal=(@@map_arr[:ocn_htmlseg].empty?) ? read_map_ocn_htmlseg : @@map_arr[:ocn_htmlseg].dup
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -479,7 +479,7 @@ module SiSU_DAL
       reset
       data=@data
       data=SiSU_DAL_Insertions::Insertions.new(@md,data).expand_insertions?                                              # dal_expand_insertions.rb
-      data=SiSU_DAL_SubstituteAndInsert::SI.new(@md,data).substitutions_and_insertions?                                  # dal_substitutions_and_insertions.rb
+      data=SiSU_DAL_MiscArrangeText::SI.new(@md,data).prepare_text                                                       # dal_misc_arrange.rb
       data,metadata=SiSU_DAL_DocumentStructureExtract::Build.new(@md,data).identify_parts                                # dal_doc_str.rb
       data=SiSU_DAL_Syntax::Markup.new(@md,data).songsheet                                                               # dal_syntax.rb
       data,endnote_array=SiSU_DAL_CharacterCheck::Check.new(data).character_check_and_oldstyle_endnote_array             # dal_character_check.rb
