@@ -110,145 +110,214 @@ module SiSU_DAL_Insertions
     end
     def by_language(linked_doc,lng,src=nil)
       @linked_doc,@lng,@src=linked_doc,lng,src
-      @base_path="#{@md.file.output_path.base.url}/#{@lng}"
+      @base_path="#{@md.file.output_path.base.url}/#{lng}"
+      def fnh
+        {
+          fn: @linked_doc,
+        }
+      end
+      def path_and_file(fn,pth)
+        "#{@base_path}/#{pth}/#{fn}"
+      end
       def manifest
-        "#{@base_path}/manifest/#{@linked_doc}.html"
+        fn=@md.file.base_filename.manifest(fnh)
+        path_and_file(fn,'manifest')
       end
       def html_toc
-        "#{@base_path}/html/#{@linked_doc}.html"
+        fn=@md.file.base_filename.html_segtoc(fnh)
+        "#{@base_path}/html/#{@linked_doc}/#{fn}"
       end
       def html_doc
-        "#{@base_path}/html/#{@linked_doc}.html"
+        fn=@md.file.base_filename.html_scroll(fnh)
+        path_and_file(fn,'html')
       end
       def html_concordance
-        "#{@base_path}/html/#{@linked_doc}.html"
+        fn=@md.file.base_filename.html_concordance
+        "#{@base_path}/html/#{@linked_doc}/#{fn}"
       end
       def epub
-        "#{@base_path}/epub/#{@linked_doc}.epub"
+        fn=@md.file.base_filename.epub(fnh)
+        path_and_file(fn,'epub')
       end
       def pdf_landscape
-        "#{@base_path}/pdf/#{@linked_doc}.pdf"
+        fn=@md.file.base_filename.pdf_l_a4(fnh)
+        path_and_file(fn,'pdf')
       end
       def pdf_portrait
-        "#{@base_path}/pdf/#{@linked_doc}.pdf"
+        fn=@md.file.base_filename.pdf_p_a4(fnh)
+        path_and_file(fn,'pdf')
       end
       def odt
-        "#{@base_path}/odt/#{@linked_doc}.odt"
+        fn=@md.file.base_filename.odt(fnh)
+        path_and_file(fn,'odt')
       end
       def xhtml
-        "#{@base_path}/xhtml/#{@linked_doc}.xhtml"
+        fn=@md.file.base_filename.xhtml(fnh)
+        path_and_file(fn,'xhtml')
       end
       def xml_sax
-        "#{@base_path}/xml/#{@linked_doc}.xml"
+        fn=@md.file.base_filename.xml_sax(fnh)
+        path_and_file(fn,'xml_sax')
       end
       def xml_dom
-        "#{@base_path}/xml/#{@linked_doc}.xml"
+        fn=@md.file.base_filename.xml_dom(fnh)
+        path_and_file(fn,'xml_dom')
       end
       def txt
-        "#{@base_path}/txt/#{@linked_doc}.txt"
+        fn=@md.file.base_filename.txt(fnh)
+        path_and_file(fn,'txt')
       end
       def digest
-        "#{@base_path}/digest/#{@linked_doc}.txt"
+        fn=@md.file.base_filename.hash_digest(fnh)
+        path_and_file(fn,'digest')
       end
       def source
         "#{@base_path}/src/#{@src}"
       end
       def sisupod
-        "#{@base_path}/pod/#{@src}.zip"
+        "#{@base_path}/src/#{@src}.zip"
       end
       self
     end
     def by_filetype(linked_doc,lng,src=nil)
       @linked_doc,@lng,@src=linked_doc,lng,src
+      @lc=SiSU_Env::FilenameLanguageCodeInsert.new(@md.opt,lng).language_code_insert
       @base_path="#{@md.file.output_path.base.url}"
+      def fnh
+        {
+          fn: @linked_doc,
+          lng: @lc,
+        }
+      end
+      def path_and_file(fn,pth)
+        "#{@base_path}/#{pth}/#{fn}"
+      end
       def manifest
-        "#{@base_path}/manifest/#{@linked_doc}.#{@lng}.html"
+        fn=@md.file.base_filename.manifest(fnh)
+        path_and_file(fn,'manifest')
       end
       def html_toc
-        "#{@base_path}/html/#{@linked_doc}.#{@lng}.html"
+        fn=@md.file.base_filename.html_segtoc(fnh)
+        path_and_file(fn,'html')
       end
       def html_doc
-        "#{@base_path}/html/#{@linked_doc}.#{@lng}.html"
+        fn=@md.file.base_filename.html_scroll(fnh)
+        path_and_file(fn,'html')
       end
       def html_concordance
-        "#{@base_path}/html/#{@linked_doc}.#{@lng}.html"
+        fn=@md.file.base_filename.html_concordance
+        path_and_file(fn,'html')
       end
       def epub
-        "#{@base_path}/epub/#{@linked_doc}.#{@lng}.epub"
+        fn=@md.file.base_filename.epub(fnh)
+        path_and_file(fn,'epub')
       end
       def pdf_landscape
-        "#{@base_path}/pdf/#{@linked_doc}.#{@lng}.pdf"
+        fn=@md.file.base_filename.pdf_l_a4(fnh)
+        path_and_file(fn,'pdf')
       end
       def pdf_portrait
-        "#{@base_path}/pdf/#{@linked_doc}.#{@lng}.pdf"
+        fn=@md.file.base_filename.pdf_p_a4(fnh)
+        path_and_file(fn,'pdf')
       end
       def odt
-        "#{@base_path}/odt/#{@linked_doc}.#{@lng}.odt"
+        fn=@md.file.base_filename.odt(fnh)
+        path_and_file(fn,'odt')
       end
       def xhtml
-        "#{@base_path}/xhtml/#{@linked_doc}.#{@lng}.xhtml"
+        fn=@md.file.base_filename.xhtml(fnh)
+        path_and_file(fn,'xhtml')
       end
       def xml_sax
-        "#{@base_path}/xml_sax/#{@linked_doc}.#{@lng}.xml"
+        fn=@md.file.base_filename.xml_sax(fnh)
+        path_and_file(fn,'xml_sax')
       end
       def xml_dom
-        "#{@base_path}/xml_dom/#{@linked_doc}.#{@lng}.xml"
+        fn=@md.file.base_filename.xml_dom(fnh)
+        path_and_file(fn,'xml_dom')
       end
       def txt
-        "#{@base_path}/txt/#{@linked_doc}.#{@lng}.txt"
+        fn=@md.file.base_filename.txt(fnh)
+        path_and_file(fn,'txt')
       end
       def digest
-        "#{@base_path}/digest/#{@linked_doc}.#{@lng}.txt"
+        fn=@md.file.base_filename.hash_digest(fnh)
+        path_and_file(fn,'digest')
       end
       def source
         "#{@base_path}/src/#{@src}"
       end
       def sisupod
-        "#{@base_path}/pod/#{@src}.zip"
+        "#{@base_path}/src/#{@src}.zip"
       end
       self
     end
     def by_filename(linked_doc,lng,src=nil)
       @linked_doc,@lng,@src=linked_doc,lng,src
+      @lc=SiSU_Env::FilenameLanguageCodeInsert.new(@md.opt,lng).language_code_insert
       @base_path="#{@md.file.output_path.base.url}/#{@linked_doc}"
+      def fnh
+        {
+          fn: @linked_doc,
+          lng: @lc,
+        }
+      end
+      def path_and_file(fn,pth=nil)
+        (pth.nil?) \
+        ? "#{@base_path}/#{fn}"
+        : "#{@base_path}/#{pth}/#{fn}"
+      end
       def manifest
-        "#{@base_path}/sisu_manifest.#{@lng}.html"
+        fn=@md.file.base_filename.manifest(fnh)
+        path_and_file(fn)
       end
       def html_toc
-        "#{@base_path}/toc.#{@lng}.html"
+        fn=@md.file.base_filename.html_segtoc(fnh)
+        path_and_file(fn)
       end
       def html_doc
-        "#{@base_path}/scroll.#{@lng}.html"
+        fn=@md.file.base_filename.html_scroll(fnh)
+        path_and_file(fn)
       end
       def html_concordance
-        "#{@base_path}/concordance.#{@lng}.html"
+        fn=@md.file.base_filename.html_concordance
+        path_and_file(fn)
       end
       def epub
-        "#{@base_path}/epub/#{@linked_doc}.#{@lng}.epub"
+        fn=@md.file.base_filename.epub(fnh)
+        path_and_file(fn,'epub')
       end
       def pdf_landscape
-        "#{@base_path}/landscape.#{@lng}.a4.pdf"
+        fn=@md.file.base_filename.pdf_l_a4(fnh)
+        path_and_file(fn)
       end
       def pdf_portrait
-        "#{@base_path}/portrait.#{@lng}.a4.pdf"
+        fn=@md.file.base_filename.pdf_p_a4(fnh)
+        path_and_file(fn)
       end
       def odt
-        "#{@base_path}/opendocument.#{@lng}.odt"
+        fn=@md.file.base_filename.odt(fnh)
+        path_and_file(fn)
       end
       def xhtml
-        "#{@base_path}/scroll.#{@lng}.xhtml"
+        fn=@md.file.base_filename.xhtml(fnh)
+        path_and_file(fn)
       end
       def xml_sax
-        "#{@base_path}/scroll.#{@lng}.sax.xml"
+        fn=@md.file.base_filename.xml_sax(fnh)
+        path_and_file(fn)
       end
       def xml_dom
-        "#{@base_path}/scroll.#{@lng}.dom.xml"
+        fn=@md.file.base_filename.xml_dom(fnh)
+        path_and_file(fn)
       end
       def txt
-        "#{@base_path}/plain.#{@lng}.txt"
+        fn=@md.file.base_filename.txt(fnh)
+        path_and_file(fn)
       end
       def digest
-        "#{@base_path}/digest.#{@lng}.txt"
+        fn=@md.file.base_filename.hash_digest(fnh)
+        path_and_file(fn)
       end
       def source
         "#{@base_path}/#{@src}"
@@ -263,9 +332,9 @@ module SiSU_DAL_Insertions
       tuned_file,tuned_file_tmp=[],[]
       codeblock_=false
       data.each do |para|
-        codeblock_=if para =~/^code\{/
+        codeblock_=if para =~/^(?:code\{|[`]{3}\s+code)/
           true
-        elsif para =~/^\}code/
+        elsif para =~/^(?:\}code|[`]{3}(?:\s|$))/m
           false
         else codeblock_
         end
@@ -274,6 +343,7 @@ module SiSU_DAL_Insertions
         and para =~/\{(?:~\^\s+)?(.+?)\s\[(?:\d(?:[sS]*))\]\}(?:\.\.\/\S+?\/|\S+?\.ss[tm]\b)/
           manifest=nil
           @u=SiSU_Env::InfoEnv.new.url
+          m_cmd=''
           if defined? @u.remote
             if /(?<m_pre>.+?)\{(?<m_txt>.+?)\s\[(?<m_cmd>\d[sS]*)\]\}(?<m_source>(?<m_linked_doc>\S+?)\.ss[tm]\b)(?<m_note>.*)/m =~ para
               m_pre=m_pre.strip
@@ -289,10 +359,9 @@ module SiSU_DAL_Insertions
             if /\{(?:~\^\s+)?(?<m_txt>.+?)\s\[(?<m_cmd>\d[sS]*)\]\}\.\.\/(?<m_linked_doc>\S+?)\/(?<m_note>\s+#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]})?/ =~ para
             end
           end
-          lnk={}
-          case @md.opt.dir_structure_by
+          lnk=case @md.opt.dir_structure_by
           when :language
-            lnk={
+            {
               manifest:         by_language(m_linked_doc,m_linked_doc_lang).manifest,
               html_toc:         by_language(m_linked_doc,m_linked_doc_lang).html_toc,
               html_doc:         by_language(m_linked_doc,m_linked_doc_lang).html_doc,
@@ -306,11 +375,11 @@ module SiSU_DAL_Insertions
               txt:              by_language(m_linked_doc,m_linked_doc_lang).txt,
               html_concordance: by_language(m_linked_doc,m_linked_doc_lang).html_concordance,
               digest:           by_language(m_linked_doc,m_linked_doc_lang).digest,
-              sisupod:          by_language(m_linked_doc,m_linked_doc_lang,source).sisupod,
-              source:           by_language(m_linked_doc,m_linked_doc_lang,source).source,
+              sisupod:          by_language(m_linked_doc,m_linked_doc_lang,m_source).sisupod,
+              source:           by_language(m_linked_doc,m_linked_doc_lang,m_source).source,
             }
           when :filetype
-            lnk={
+            {
               manifest:         by_filetype(m_linked_doc,m_linked_doc_lang).manifest,
               html_toc:         by_filetype(m_linked_doc,m_linked_doc_lang).html_toc,
               html_doc:         by_filetype(m_linked_doc,m_linked_doc_lang).html_doc,
@@ -324,11 +393,11 @@ module SiSU_DAL_Insertions
               txt:              by_filetype(m_linked_doc,m_linked_doc_lang).txt,
               html_concordance: by_filetype(m_linked_doc,m_linked_doc_lang).html_concordance,
               digest:           by_filetype(m_linked_doc,m_linked_doc_lang).digest,
-              sisupod:          by_filetype(m_linked_doc,m_linked_doc_lang,source).sisupod,
-              source:           by_filetype(m_linked_doc,m_linked_doc_lang,source).source,
+              sisupod:          by_filetype(m_linked_doc,m_linked_doc_lang,m_source).sisupod,
+              source:           by_filetype(m_linked_doc,m_linked_doc_lang,m_source).source,
             }
           else
-            lnk={
+            {
               manifest:         by_filename(m_linked_doc,m_linked_doc_lang).manifest,
               html_toc:         by_filename(m_linked_doc,m_linked_doc_lang).html_toc,
               html_doc:         by_filename(m_linked_doc,m_linked_doc_lang).html_doc,
@@ -342,13 +411,13 @@ module SiSU_DAL_Insertions
               txt:              by_filename(m_linked_doc,m_linked_doc_lang).txt,
               html_concordance: by_filename(m_linked_doc,m_linked_doc_lang).html_concordance,
               digest:           by_filename(m_linked_doc,m_linked_doc_lang).digest,
-              sisupod:          by_filename(m_linked_doc,m_linked_doc_lang,source).sisupod,
-              source:           by_filename(m_linked_doc,m_linked_doc_lang,source).source,
+              sisupod:          by_filename(m_linked_doc,m_linked_doc_lang,m_source).sisupod,
+              source:           by_filename(m_linked_doc,m_linked_doc_lang,m_source).source,
             }
           end
           linked_title="#{m_pre}{#{m_txt} }#{lnk[:manifest]}#{m_note}\n\n"
           tuned_file_tmp << linked_title
-          output_filetypes=output_filetypes_in_cmd(cmd,lnk)
+          output_filetypes=output_filetypes_in_cmd(m_cmd,lnk)
           output_filetypes[:gen].each do |o_f|
             describe = o_f
             if describe
