@@ -109,7 +109,7 @@ module SiSU_DbColumns
             IS 'metadata full document title [DC1]';}
         end
         def tuple
-          t=if defined? @md.title.full \
+          if defined? @md.title.full \
           and @md.title.full=~/\S+/
             txt=@md.title.full
             txt=special_character_escape(txt)
@@ -131,7 +131,7 @@ module SiSU_DbColumns
             IS 'metadata main document title';}
         end
         def tuple
-          t=if defined? @md.title.main \
+          if defined? @md.title.main \
           and @md.title.main=~/\S+/
             txt=@md.title.main
             txt=special_character_escape(txt)
@@ -153,7 +153,7 @@ module SiSU_DbColumns
             IS 'metadata document subtitle';}
         end
         def tuple
-          t=if defined? @md.title.sub \
+          if defined? @md.title.sub \
           and @md.title.sub=~/\S+/
             txt=@md.title.sub
             txt=special_character_escape(txt)
@@ -175,7 +175,7 @@ module SiSU_DbColumns
             IS 'metadata document short title if any';}
         end
         def tuple
-          t=if defined? @md.title.short \
+          if defined? @md.title.short \
           and @md.title.short=~/\S+/
             txt=@md.title.short
             txt=special_character_escape(txt)
@@ -197,7 +197,7 @@ module SiSU_DbColumns
             IS 'metadata document edition (version)';}
         end
         def tuple
-          t=if defined? @md.title.edition \
+          if defined? @md.title.edition \
           and @md.title.edition=~/\S+/
             txt=@md.title.edition
             txt=special_character_escape(txt)
@@ -219,7 +219,7 @@ module SiSU_DbColumns
             IS 'metadata document notes associated with title';}
         end
         def tuple
-          t=if defined? @md.title.note \
+          if defined? @md.title.note \
           and @md.title.note=~/\S+/
             txt=@md.title.note
             txt=special_character_escape(txt)
@@ -241,7 +241,7 @@ module SiSU_DbColumns
             IS 'metadata document language [DC12]';}
         end
         def tuple
-          t=if @lang.list[@md.opt.lng][:n]
+          if @lang.list[@md.opt.lng][:n]
             txt=@lang.list[@md.opt.lng][:n]
             txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
@@ -262,7 +262,7 @@ module SiSU_DbColumns
             IS 'metadata document language iso code';}
         end
         def tuple
-          t=if defined? @md.opt.lng \
+          if defined? @md.opt.lng \
           and @md.opt.lng=~/\S+/
             txt=@md.opt.lng
             txt=special_character_escape(txt)
@@ -298,7 +298,7 @@ module SiSU_DbColumns
            IS 'metadata document author (creator) [DC2]';}
         end
         def tuple
-          t=if defined? @md.creator.author_detail \
+          if defined? @md.creator.author_detail \
           and @md.creator.author_detail.is_a?(Array) \
           and @md.creator.author_detail.length > 0
             txt=''
@@ -325,7 +325,7 @@ module SiSU_DbColumns
            IS 'metadata document author honorific (title e.g, Ms. Dr. Prof.)';}
         end
         def tuple
-          t=if defined? @md.creator.author_hon \
+          if defined? @md.creator.author_hon \
           and @md.creator.author_hon=~/\S+/
             txt=@md.creator.author_hon
             txt=special_character_escape(txt)
@@ -347,7 +347,7 @@ module SiSU_DbColumns
            IS 'metadata nationality of document author (creator)';}
         end
         def tuple
-          t=if defined? @md.creator.author_nationality_detail \
+          if defined? @md.creator.author_nationality_detail \
           and @md.creator.author_nationality=~/\S+/
             txt=@md.creator.author_nationality_detail
             txt=special_character_escape(txt)
@@ -369,7 +369,7 @@ module SiSU_DbColumns
            IS 'metadata document editor name(s)';}
         end
         def tuple
-          t=if defined? @md.creator.editor_detail \
+          if defined? @md.creator.editor_detail \
           and @md.creator.editor_detail.is_a?(Array) \
           and @md.creator.editor_detail.length > 0
             txt=@md.creator.editor_detail #dc
@@ -397,7 +397,7 @@ module SiSU_DbColumns
            IS 'metadata document contributor name(s) [DC6]';}
         end
         def tuple
-          t=if defined? @md.creator.contributor_detail \
+          if defined? @md.creator.contributor_detail \
           and @md.creator.contributor_detail.is_a?(Array) \
           and @md.creator.contributor_detail.length > 0
             txt=@md.creator.contributor_detail #dc
@@ -425,7 +425,7 @@ module SiSU_DbColumns
            IS 'metadata document illustrator name(s)';}
         end
         def tuple
-          t=if defined? @md.creator.illustrator_detail \
+          if defined? @md.creator.illustrator_detail \
           and @md.creator.illustrator_detail.is_a?(Array) \
           and @md.creator.illustrator_detail.length > 0
             txt=@md.creator.illustrator_detail
@@ -453,7 +453,7 @@ module SiSU_DbColumns
            IS 'metadata document photographer name(s)';}
         end
         def tuple
-          t=if defined? @md.creator.photographer_detail \
+          if defined? @md.creator.photographer_detail \
           and @md.creator.photographer_detail.is_a?(Array) \
           and @md.creator.photographer_detail.length > 0
             txt=@md.creator.photographer_detail
@@ -481,7 +481,7 @@ module SiSU_DbColumns
            IS 'metadata document translator name(s)';}
         end
         def tuple
-          t=if defined? @md.creator.translator_detail \
+          if defined? @md.creator.translator_detail \
           and @md.creator.translator_detail.is_a?(Array) \
           and @md.creator.translator_detail.length > 0
             txt=''
@@ -508,7 +508,7 @@ module SiSU_DbColumns
            IS 'metadata document prepared by name(s)';}
         end
         def tuple
-          t=if defined? @md.creator.prepared_by_detail \
+          if defined? @md.creator.prepared_by_detail \
           and @md.creator.prepared_by_detail.is_a?(Array) \
           and @md.creator.prepared_by_detail.length > 0
             txt=@md.creator.prepared_by_detail
@@ -536,7 +536,7 @@ module SiSU_DbColumns
            IS 'metadata document digitized by name(s)';}
         end
         def tuple
-          t=if defined? @md.creator.digitized_by_detail \
+          if defined? @md.creator.digitized_by_detail \
           and @md.creator.digitized_by_detail.is_a?(Array) \
           and @md.creator.digitized_by_detail.length > 0
             txt=@md.creator.digitized_by_detail
@@ -564,7 +564,7 @@ module SiSU_DbColumns
            IS 'metadata document audio by name(s)';}
         end
         def tuple
-          t=if defined? @md.creator.audio_detail \
+          if defined? @md.creator.audio_detail \
           and @md.creator.audio_detail.is_a?(Array) \
           and @md.creator.audio_detail.length > 0
             txt=@md.creator.audio_detail
@@ -592,7 +592,7 @@ module SiSU_DbColumns
            IS 'metadata document video by name(s)';}
         end
         def tuple
-          t=if defined? @md.creator.video_detail \
+          if defined? @md.creator.video_detail \
           and @md.creator.video_detail.is_a?(Array) \
           and @md.creator.video_detail.length > 0
             txt=''
@@ -631,7 +631,7 @@ module SiSU_DbColumns
            IS 'metadata document language';}
         end
         def tuple
-          t=if @lang.list[@md.opt.lng][:n]
+          if @lang.list[@md.opt.lng][:n]
             txt=@lang.list[@md.opt.lng][:n]
             txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
@@ -653,7 +653,7 @@ module SiSU_DbColumns
         end
         def tuple
           #modify check, is now required, SiSUv3d_
-          t=if defined? @md.opt.lng \
+          if defined? @md.opt.lng \
           and @md.opt.lng=~/\S+/
             txt=@md.opt.lng
             txt=special_character_escape(txt)
@@ -675,7 +675,7 @@ module SiSU_DbColumns
            IS 'metadata original document/text language';}
         end
         def tuple
-          t=if defined? @md.language.original \
+          if defined? @md.language.original \
           and @md.language.original=~/\S+/
             txt=@md.language.original
             txt=special_character_escape(txt)
@@ -697,7 +697,7 @@ module SiSU_DbColumns
            IS 'metadata document language';}
         end
         def tuple
-          t=if defined? @md.language.original_char \
+          if defined? @md.language.original_char \
           and @md.language.original_char=~/\S+/
             txt=@md.language.original_char
             txt=special_character_escape(txt)
@@ -733,7 +733,7 @@ module SiSU_DbColumns
            IS 'metadata date added to site';}
         end
         def tuple
-          t=if defined? @md.date.added_to_site \
+          if defined? @md.date.added_to_site \
           and @md.date.added_to_site=~/\S+/
             txt=@md.date.added_to_site
             txt=special_character_escape(txt)
@@ -755,7 +755,7 @@ module SiSU_DbColumns
            IS 'metadata date added to site [DC]';}
         end
         def tuple
-          t=if defined? @md.date.available \
+          if defined? @md.date.available \
           and @md.date.available=~/\S+/
             txt=@md.date.available
             txt=special_character_escape(txt)
@@ -777,7 +777,7 @@ module SiSU_DbColumns
            IS 'metadata date created [DC]';}
         end
         def tuple
-          t=if defined? @md.date.created \
+          if defined? @md.date.created \
           and @md.date.created=~/\S+/
             txt=@md.date.created
             txt=special_character_escape(txt)
@@ -799,7 +799,7 @@ module SiSU_DbColumns
            IS 'metadata date issued [DC]';}
         end
         def tuple
-          t=if defined? @md.date.issued \
+          if defined? @md.date.issued \
           and @md.date.issued=~/\S+/
             txt=@md.date.issued
             txt=special_character_escape(txt)
@@ -821,7 +821,7 @@ module SiSU_DbColumns
            IS 'metadata date modified [DC]';}
         end
         def tuple
-          t=if defined? @md.date.modified \
+          if defined? @md.date.modified \
           and @md.date.modified=~/\S+/
             txt=@md.date.modified
             txt=special_character_escape(txt)
@@ -843,7 +843,7 @@ module SiSU_DbColumns
            IS 'metadata date published [DC7]';}
         end
         def tuple
-          t=if defined? @md.date.published \
+          if defined? @md.date.published \
           and @md.date.published=~/\S+/
             txt=@md.date.published
             txt=special_character_escape(txt)
@@ -865,7 +865,7 @@ module SiSU_DbColumns
            IS 'metadata date valid [DC]';}
         end
         def tuple
-          t=if defined? @md.date.valid \
+          if defined? @md.date.valid \
           and @md.date.valid=~/\S+/
             txt=@md.date.valid
             txt=special_character_escape(txt)
@@ -887,7 +887,7 @@ module SiSU_DbColumns
            IS 'metadata date translated';}
         end
         def tuple
-          t=if defined? @md.date.translated \
+          if defined? @md.date.translated \
           and @md.date.translated=~/\S+/
             txt=@md.date.translated
             txt=special_character_escape(txt)
@@ -909,7 +909,7 @@ module SiSU_DbColumns
            IS 'metadata date of original publication';}
         end
         def tuple
-          t=if defined? @md.date.original_publication \
+          if defined? @md.date.original_publication \
           and @md.date.original_publication=~/\S+/
             txt=@md.date.original_publication
             txt=special_character_escape(txt)
@@ -932,7 +932,7 @@ module SiSU_DbColumns
            IS 'metadata date of sisu generation of document, automatically populated';}
         end
         def tuple                      #choose other representation of time
-          t=if defined? @md.generated \
+          if defined? @md.generated \
           and @md.generated.to_s=~/\S+/
             txt=@md.generated.to_s
             txt=special_character_escape(txt)
@@ -958,7 +958,7 @@ module SiSU_DbColumns
            IS 'metadata document publisher [DC5]';}
         end
         def tuple
-          t=if defined? @md.publisher \
+          if defined? @md.publisher \
           and @md.publisher=~/\S+/
             txt=@md.publisher
             txt=special_character_escape(txt)
@@ -1011,7 +1011,7 @@ module SiSU_DbColumns
            IS 'metadata document original publisher [DC5]';}
         end
         def tuple
-          t=if defined? @md.original.publisher \
+          if defined? @md.original.publisher \
           and @md.original.publisher=~/\S+/
             txt=@md.original.publisher
             txt=special_character_escape(txt)
@@ -1033,7 +1033,7 @@ module SiSU_DbColumns
            IS 'metadata document original language';}
         end
         def tuple
-          t=if defined? @md.original.language \
+          if defined? @md.original.language \
           and @md.original.language=~/\S+/
             txt=@md.original.language
             txt=special_character_escape(txt)
@@ -1055,7 +1055,7 @@ module SiSU_DbColumns
            IS 'metadata document original language iso character';}
         end
         def tuple
-          t=if defined? @md.original.language_char \
+          if defined? @md.original.language_char \
           and @md.original.language_char=~/\S+/
             txt=@md.original.language_char
             txt=special_character_escape(txt)
@@ -1077,7 +1077,7 @@ module SiSU_DbColumns
            IS 'metadata document original source [DC11]';}
         end
         def tuple
-          t=if defined? @md.original.source \
+          if defined? @md.original.source \
           and @md.original.source=~/\S+/
             txt=@md.original.source
             txt=special_character_escape(txt)
@@ -1099,7 +1099,7 @@ module SiSU_DbColumns
            IS 'metadata document original institution';}
         end
         def tuple
-          t=if defined? @md.original.institution \
+          if defined? @md.original.institution \
           and @md.original.institution=~/\S+/
             txt=@md.original.institution
             txt=special_character_escape(txt)
@@ -1121,7 +1121,7 @@ module SiSU_DbColumns
            IS 'metadata document original nationality';}
         end
         def tuple
-          t=if defined? @md.original.nationality \
+          if defined? @md.original.nationality \
           and @md.original.nationality=~/\S+/
             txt=@md.original.nationality
             txt=special_character_escape(txt)
@@ -1158,7 +1158,7 @@ module SiSU_DbColumns
            IS 'metadata rights associated with document (composite) [DC15]';}
         end
         def tuple
-          t=if defined? @md.rights.all \
+          if defined? @md.rights.all \
           and @md.rights.all=~/\S+/
             txt=@md.rights.all
             txt=special_character_escape(txt)
@@ -1180,7 +1180,7 @@ module SiSU_DbColumns
            IS 'metadata copyright associated for document text';}
         end
         def tuple
-          t=if defined? @md.rights.copyright_text \
+          if defined? @md.rights.copyright_text \
           and @md.rights.copyright_text=~/\S+/
             txt=@md.rights.copyright_text
             txt=special_character_escape(txt)
@@ -1202,7 +1202,7 @@ module SiSU_DbColumns
            IS 'metadata copyright associated for document text translation (if any)';}
         end
         def tuple
-          t=if defined? @md.rights.copyright_translation \
+          if defined? @md.rights.copyright_translation \
           and @md.rights.copyright_translation=~/\S+/
             txt=@md.rights.copyright_translation
             txt=special_character_escape(txt)
@@ -1224,7 +1224,7 @@ module SiSU_DbColumns
            IS 'metadata copyright associated for document text illustrations (if any)';}
         end
         def tuple
-          t=if defined? @md.rights.copyright_illustrations \
+          if defined? @md.rights.copyright_illustrations \
           and @md.rights.copyright_illustrations=~/\S+/
             txt=@md.rights.copyright_illustrations
             txt=special_character_escape(txt)
@@ -1246,7 +1246,7 @@ module SiSU_DbColumns
            IS 'metadata copyright associated for document text photographs (if any)';}
         end
         def tuple
-          t=if defined? @md.rights.copyright_photographs \
+          if defined? @md.rights.copyright_photographs \
           and @md.rights.copyright_photographs=~/\S+/
             txt=@md.rights.copyright_photographs
             txt=special_character_escape(txt)
@@ -1268,7 +1268,7 @@ module SiSU_DbColumns
            IS 'metadata copyright associated for document text preparation (if any)';}
         end
         def tuple
-          t=if defined? @md.rights.copyright_preparation \
+          if defined? @md.rights.copyright_preparation \
           and @md.rights.copyright_preparation=~/\S+/
             txt=@md.rights.copyright_preparation
             txt=special_character_escape(txt)
@@ -1290,7 +1290,7 @@ module SiSU_DbColumns
            IS 'metadata copyright associated for document text digitization (if any)';}
         end
         def tuple
-          t=if defined? @md.rights.copyright_digitization \
+          if defined? @md.rights.copyright_digitization \
           and @md.rights.copyright_digitization=~/\S+/
             txt=@md.rights.copyright_digitization
             txt=special_character_escape(txt)
@@ -1312,7 +1312,7 @@ module SiSU_DbColumns
            IS 'metadata copyright associated for document text audio (if any)';}
         end
         def tuple
-          t=if defined? @md.rights.copyright_audio \
+          if defined? @md.rights.copyright_audio \
           and @md.rights.copyright_audio=~/\S+/
             txt=@md.rights.copyright_audio
             txt=special_character_escape(txt)
@@ -1334,7 +1334,7 @@ module SiSU_DbColumns
            IS 'metadata copyright associated for document text video (if any)';}
         end
         def tuple
-          t=if defined? @md.rights.copyright_video \
+          if defined? @md.rights.copyright_video \
           and @md.rights.copyright_video=~/\S+/
             txt=@md.rights.copyright_video
             txt=special_character_escape(txt)
@@ -1356,7 +1356,7 @@ module SiSU_DbColumns
            IS 'metadata license granted for use of document if any)';}
         end
         def tuple
-          t=if defined? @md.rights.license \
+          if defined? @md.rights.license \
           and @md.rights.license=~/\S+/
             txt=@md.rights.license
             txt=special_character_escape(txt)
@@ -1384,7 +1384,7 @@ module SiSU_DbColumns
            IS 'metadata identifier document Online Computer Library Center number';}
         end
         def tuple
-          t=if defined? @md.identifier.oclc \
+          if defined? @md.identifier.oclc \
           and @md.identifier.oclc=~/\S+/
             txt=@md.identifier.oclc
             txt=special_character_escape(txt)
@@ -1406,7 +1406,7 @@ module SiSU_DbColumns
            IS 'metadata identifier document isbn (if any)';}
         end
         def tuple
-          t=if defined? @md.identifier.isbn \
+          if defined? @md.identifier.isbn \
           and @md.identifier.isbn=~/\S+/
             txt=@md.identifier.isbn
             txt=special_character_escape(txt)
@@ -1438,7 +1438,7 @@ module SiSU_DbColumns
            IS 'metadata classify document topic register (semi-structured document subject information)';}
         end
         def tuple
-          t=if defined? @md.classify.topic_register \
+          if defined? @md.classify.topic_register \
           and @md.classify.topic_register=~/\S+/
             txt=@md.classify.topic_register
             txt=special_character_escape(txt)
@@ -1460,7 +1460,7 @@ module SiSU_DbColumns
            IS 'metadata classify document subject matter [DC3]';}
         end
         def tuple
-          t=if defined? @md.classify.subject \
+          if defined? @md.classify.subject \
           and @md.classify.subject=~/\S+/
             txt=@md.classify.subject
             txt=special_character_escape(txt)
@@ -1482,7 +1482,7 @@ module SiSU_DbColumns
            IS 'metadata classify document Library of Congress';}
         end
         def tuple
-          t=if defined? @md.classify.loc \
+          if defined? @md.classify.loc \
           and @md.classify.loc=~/\S+/
             txt=@md.classify.loc
             txt=special_character_escape(txt)
@@ -1504,7 +1504,7 @@ module SiSU_DbColumns
            IS 'metadata classify document Dewey';}
         end
         def tuple
-          t=if defined? @md.classify.dewey \
+          if defined? @md.classify.dewey \
           and @md.classify.dewey=~/\S+/
             txt=@md.classify.dewey
             txt=special_character_escape(txt)
@@ -1526,7 +1526,7 @@ module SiSU_DbColumns
            IS 'metadata classify document keywords';}
         end
         def tuple
-          t=if defined? @md.classify.keywords \
+          if defined? @md.classify.keywords \
           and @md.classify.keywords=~/\S+/
             txt=@md.classify.keywords
             txt=special_character_escape(txt)
@@ -1563,7 +1563,7 @@ module SiSU_DbColumns
            IS 'metadata document notes abstract';}
         end
         def tuple
-          t=if defined? @md.notes.abstract \
+          if defined? @md.notes.abstract \
           and @md.notes.abstract=~/\S+/
             txt=@md.notes.abstract
             txt=special_character_escape(txt)
@@ -1585,7 +1585,7 @@ module SiSU_DbColumns
            IS 'metadata document notes description [DC4]';}
         end
         def tuple
-          t=if defined? @md.notes.description \
+          if defined? @md.notes.description \
           and @md.notes.description=~/\S+/
             txt=@md.notes.description
             txt=special_character_escape(txt)
@@ -1607,7 +1607,7 @@ module SiSU_DbColumns
            IS 'metadata document notes comment';}
         end
         def tuple
-          t=if defined? @md.notes.comment \
+          if defined? @md.notes.comment \
           and @md.notes.comment=~/\S+/
             txt=@md.notes.comment
             txt=special_character_escape(txt)
@@ -1629,7 +1629,7 @@ module SiSU_DbColumns
            IS 'metadata classify document coverage [DC14]';}
         end
         def tuple
-          t=if defined? @md.classify.coverage \
+          if defined? @md.classify.coverage \
           and @md.classify.coverage=~/\S+/
             txt=@md.classify.coverage
             txt=special_character_escape(txt)
@@ -1651,7 +1651,7 @@ module SiSU_DbColumns
            IS 'metadata classify document relation [DC13]';}
         end
         def tuple
-          t=if defined? @md.classify.relation \
+          if defined? @md.classify.relation \
           and @md.classify.relation=~/\S+/
             txt=@md.classify.relation
             txt=special_character_escape(txt)
@@ -1673,7 +1673,7 @@ module SiSU_DbColumns
            IS 'metadata document notes history';}
         end
         def tuple
-          t=if defined? @md.notes.history \
+          if defined? @md.notes.history \
           and @md.notes.history=~/\S+/
             txt=@md.notes.history
             txt=special_character_escape(txt)
@@ -1695,7 +1695,7 @@ module SiSU_DbColumns
            IS 'metadata notes document type [DC8]';}
         end
         def tuple
-          t=if defined? @md.notes.type \
+          if defined? @md.notes.type \
           and @md.notes.type=~/\S+/
             txt=@md.notes.type
             txt=special_character_escape(txt)
@@ -1717,7 +1717,7 @@ module SiSU_DbColumns
            IS 'metadata classify document format [DC9]';}
         end
         def tuple
-          t=if defined? @md.classify.format \
+          if defined? @md.classify.format \
           and @md.classify.format=~/\S+/
             txt=@md.classify.format
             txt=special_character_escape(txt)
@@ -1739,7 +1739,7 @@ module SiSU_DbColumns
            IS 'metadata document notes prefix';}
         end
         def tuple
-          t=if defined? @md.notes.prefix \
+          if defined? @md.notes.prefix \
           and @md.notes.prefix=~/\S+/
             txt=@md.notes.prefix
             txt=special_character_escape(txt)
@@ -1761,7 +1761,7 @@ module SiSU_DbColumns
            IS 'metadata document notes prefix_a';}
         end
         def tuple
-          t=if defined? @md.notes.prefix_a \
+          if defined? @md.notes.prefix_a \
           and @md.notes.prefix_a=~/\S+/
             txt=@md.notes.prefix_a
             txt=special_character_escape(txt)
@@ -1783,7 +1783,7 @@ module SiSU_DbColumns
            IS 'metadata document notes prefix_b';}
         end
         def tuple
-          t=if defined? @md.notes.prefix_b \
+          if defined? @md.notes.prefix_b \
           and @md.notes.prefix_b=~/\S+/
             txt=@md.notes.prefix_b
             txt=special_character_escape(txt)
@@ -1805,7 +1805,7 @@ module SiSU_DbColumns
            IS 'metadata document notes suffix';}
         end
         def tuple
-          t=if defined? @md.notes.suffix \
+          if defined? @md.notes.suffix \
           and @md.notes.suffix=~/\S+/
             txt=@md.notes.suffix
             txt=special_character_escape(txt)
@@ -1830,7 +1830,7 @@ module SiSU_DbColumns
            IS 'sisu markup source text filename';}
         end
         def tuple
-          t=if defined? @md.fns \
+          if defined? @md.fns \
           and @md.fns=~/\S+/
             txt=@md.fns
             txt=special_character_escape(txt)
@@ -1853,7 +1853,7 @@ module SiSU_DbColumns
             IS 'sisu markup source text fingerprint, hash digest sha256 (or md5)';}
         end
         def tuple
-          t=if defined? @md.dgst \
+          if defined? @md.dgst \
           and @md.dgst.is_a?(Array) \
           and @md.dgst[1]=~/\S+/
             txt=@md.dgst[1]
@@ -1875,7 +1875,7 @@ module SiSU_DbColumns
             IS 'sisu markup source text file size';}
         end
         def tuple
-         t=if defined? @md.filesize \
+         if defined? @md.filesize \
          and @md.filesize=~/\S+/
            txt=@md.filesize
            txt=special_character_escape(txt)
@@ -1897,7 +1897,7 @@ module SiSU_DbColumns
             IS 'sisu markup source text word count';}
         end
         def tuple
-          t=if defined? @md.wc_words \
+          if defined? @md.wc_words \
           and @md.wc_words=~/\S+/
             txt=@md.wc_words
             txt=special_character_escape(txt)
@@ -1919,7 +1919,7 @@ module SiSU_DbColumns
            IS 'sisu markup source text (if shared)';}
         end
         def tuple
-          t=if @md.opt.mod.inspect=~/import|update/ \
+          if @md.opt.mod.inspect=~/import|update/ \
           and FileTest.exist?(@md.fns)
             ["#{name}, ","'#{@sisutxt}', "]
           else ['','']
@@ -1943,7 +1943,7 @@ module SiSU_DbColumns
             IS 'document full text clean, searchable';}
         end
         def tuple
-          t=if @md.opt.mod.inspect=~/import|update/ \
+          if @md.opt.mod.inspect=~/import|update/ \
           and  FileTest.exist?(@md.fns)
             ["#{name}, ","'#{@fulltext}', "]
           else ['','']
@@ -1964,7 +1964,7 @@ module SiSU_DbColumns
            IS 'metadata document links';}
         end
         def tuple
-          t=if defined? @md.links \
+          if defined? @md.links \
           and @md.links=~/\S+/
             txt=@md.links
             txt=special_character_escape(txt)
