@@ -171,7 +171,7 @@ module SiSU_DbImport
           STDERR.puts "Error code: #{e.err}"
           STDERR.puts "Error message: #{e.errstr}"
           STDERR.puts "Error SQLSTATE: #{e.state}"
-          SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
           sqlfn="#{@env.processing_path.sql}/#{@md.fnb}.sql"
@@ -184,7 +184,7 @@ module SiSU_DbImport
             puts "#{__FILE__}:#{__LINE__}"
           end
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
           sqlfn="#{@env.processing_path.sql}/#{@md.fnb}.sql"
@@ -569,7 +569,7 @@ module SiSU_DbImport
           end
         end
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -643,8 +643,8 @@ module SiSU_DbImport
         if FileTest.file?("#{@md.file.output_path.txt.dir}/#{@md.file.base_filename.txt}")==true
           f[:txt],u[:txt]='plaintext,', "'#{@md.file.output_path.txt.url}/#{@md.file.base_filename.txt}',"
         end
-        if FileTest.file?("#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_seg}")==true
-          f[:html_toc],u[:html_toc]='html_toc,', "'#{@md.file.output_path.html_seg.url}/#{@md.file.base_filename.html_seg}',"
+        if FileTest.file?("#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}")==true
+          f[:html_toc],u[:html_toc]='html_toc,', "'#{@md.file.output_path.html_seg.url}/#{@md.file.base_filename.html_segtoc}',"
         end
         if FileTest.file?("#{@md.file.output_path.html_scroll.dir}/#{@md.file.base_filename.html_scroll}")==true
           f[:html_doc],u[:html_doc]='html_doc,', "'#{@md.file.output_path.html_scroll.url}/#{@md.file.base_filename.html_scroll}',"
@@ -702,7 +702,7 @@ module SiSU_DbImport
         t=SiSU_DbTuple::LoadUrls.new(@conn,f,u,@@id_t,@opt,@file_maint)
         tuple=t.tuple
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
