@@ -737,10 +737,11 @@ WOK
         end
       end
       def do_hash_md(lng,attrib,hash)
+        lang_code_insert=SiSU_Env::FilenameLanguageCodeInsert.new(@opt,lng).language_code_insert
         manifest_at=if @env.output_dir_structure.by? == :language
-          hash[:file] + '.html'
+          hash[:file] + Sfx[:html]
         elsif @env.output_dir_structure.by? == :filetype
-          hash[:file] + '.' + lng +  '.html'
+          hash[:file] + lang_code_insert +  Sfx[:html]
         elsif @env.output_dir_structure.by? == :filename
           "./#{hash[:file]}/#{hash[:page]}"
         else '' #error
