@@ -187,7 +187,7 @@ module SiSU_HTML_Format
         else
           @md.file.output_path.html_seg.rel_image
         end
-        dir=SiSU_Env::FileOp.new(@md)
+        SiSU_Env::FileOp.new(@md)
         button +=%{   <p class="tiny_left"><a href="#{@md.make.home_button_image[:link]}" target="_top"><img border="0" src="#{image_path}/#{@md.make.home_button_image[:home_button]}"  width="#{@md.make.home_button_image[:w]}" height="#{@md.make.home_button_image[:h]}" alt="home icon --&gt;" /></a></p>\n}
       elsif @md.home_button_links.is_a?(Array)
         @md.home_button_links.each do |links|
@@ -221,7 +221,7 @@ module SiSU_HTML_Format
     end
     def scroll(text)
       if @md.fns =~ /\.(?:-|ssm\.)?sst$/
-        scroll=%{<td align="center" bgcolor=#{@vz.color_band2}>
+        %{<td align="center" bgcolor=#{@vz.color_band2}>
   <a href="#{Xx[:html_relative1]}html/#{@file.base_filename.html_scroll}" target="_top">
     #{text}
   </a>
@@ -301,7 +301,7 @@ module SiSU_HTML_Format
     end
     def scroll_head_navigation_band
       if @make.build.html_top_band?
-        search_and_manifest=<<WOK
+        <<WOK
 <td align="center" width="60%">
   #{make_scroll_search_form_and_manifest_link}
 </td>
@@ -380,7 +380,7 @@ WOK
     end
     def make_scroll_search_form_and_manifest_link
       wgt=SiSU_HTML_Format::Widget.new(@md)
-      scroll=%{<td align="center" bgcolor=#{@vz.color_band2}>
+      %{<td align="center" bgcolor=#{@vz.color_band2}>
   #{@vz.nav_txt_doc_link}
 </td>
 }
@@ -391,7 +391,7 @@ WOK
 </tr></table>}
     end
     def make_scroll_seg_pdf
-      manifest=scroll=seg=''
+      seg=''
       wgt=SiSU_HTML_Format::Widget.new(@md)
       seg=%{<td align="center" bgcolor=#{@vz.color_band2}>
   #{@vz.nav_txt_toc_link}
@@ -405,7 +405,6 @@ WOK
 </tr></table>}
     end
     def make_concordance
-      manifest=scroll=seg=''
       wgt=SiSU_HTML_Format::Widget.new(@md)
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
@@ -732,7 +731,6 @@ WOK
 #{@vz.table_close}}
     end
     def toc_next2
-      pre,nxt=false,true
       toc_nav(false,true).dup
     end
     def toc_pre_next2
@@ -931,7 +929,7 @@ WOK
       if defined? dob.tags \
       and dob.tags.length > 0 # insert tags "hypertargets"
         dob.tags.each do |t|
-          tags=tags +%{<named id="#{t}" />}
+          tags=tags << %{<named id="#{t}" />}
         end
       end
       tags
@@ -941,7 +939,7 @@ WOK
       if defined? dob.tags \
       and dob.tags.length > 0 # insert tags "hypertargets"
         dob.tags.each do |t|
-          tags=tags +%{<a name="#{t}" ></a>}
+          tags=tags << %{<a name="#{t}" ></a>}
         end
       end
       tags
