@@ -89,6 +89,7 @@ module SiSU
     end
   end
   class OptionLoopFiles
+    attr_reader :opt
     def initialize(opt)
       @opt=opt
       @r=Px[:lng_lst_rgx]
@@ -185,22 +186,22 @@ module SiSU
       @@n_do=0
     end
     def remote_put_base_site_rsync                         # -CR
-      puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:cyan) if @opt.act[:maintenance][:set] ==:on
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) if @opt.act[:maintenance][:set] ==:on
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).rsync_base
     end
     def remote_put_base_site_rsync_match                   # -CCRZ
-      puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:cyan) if @opt.act[:maintenance][:set] ==:on
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) if @opt.act[:maintenance][:set] ==:on
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).rsync_base_sync
     end
     def remote_put_base_site                               # -Cr
-      puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:cyan) if @opt.act[:maintenance][:set] ==:on
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) if @opt.act[:maintenance][:set] ==:on
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).scp_base
     end
     def remote_put_base_site_all                           # -CCr
-      puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:cyan) if @opt.act[:maintenance][:set] ==:on
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) if @opt.act[:maintenance][:set] ==:on
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).scp_base_all
     end
@@ -220,10 +221,10 @@ module SiSU
       SiSU_Webserv::WebrickStart.new
     end
     def not_found
-      puts "\n#{@cX.fuschia}FILE NOT FOUND:#{@cX.off} << #{@opt.fns} >> - requested #{@opt.cmd} processing skipped\n"
+      puts "\n#{@cX.fuchsia}FILE NOT FOUND:#{@cX.off} << #{@opt.fns} >> - requested #{@opt.cmd} processing skipped\n"
     end
     def convert_name_message(fns,type,i,o,rune)
-      %{\nIn filename: "#{@cX.fuschia}#{fns}#{@cX.off}" << #{type} >> #{@cX.fuschia}is apre 0.36 markup filename.#{@cX.off} #{@cX.brown}Please rename your file.#{@cX.off}\n\tAs of sisu-0.37, SiSU markup files with #{@cX.brown}the extensions #{i} should be re-named #{o}#{@cX.off}\n\tif you have the program called 'rename' installed, the following rune should do the trick:\n\t\t#{rune}\n\talternatively try:\n\t\tsisu --convert --36to37 #{fns}\n\trequested #{@opt.cmd} processing skipped\n}
+      %{\nIn filename: "#{@cX.fuchsia}#{fns}#{@cX.off}" << #{type} >> #{@cX.fuchsia}is apre 0.36 markup filename.#{@cX.off} #{@cX.brown}Please rename your file.#{@cX.off}\n\tAs of sisu-0.37, SiSU markup files with #{@cX.brown}the extensions #{i} should be re-named #{o}#{@cX.off}\n\tif you have the program called 'rename' installed, the following rune should do the trick:\n\t\t#{rune}\n\talternatively try:\n\t\tsisu --convert --36to37 #{fns}\n\trequested #{@opt.cmd} processing skipped\n}
     end
     def not_recognised
       case @opt.fns
@@ -237,9 +238,9 @@ module SiSU
         puts convert_name_message(@opt.fns,type,'.r1 .r2 and .r3','.sst',rune)
         puts %{\n\tNote also that you will need to change the names of the files called/required\n\twithin the document text to build the composite document\n\t\t.s1 .s2 .s3 should be .sst \n\t\t.si should be .ssi\n\trequested #{@opt.cmd} processing skipped\n}
       when /(\.ssi)$/
-        puts "\n#{@cX.fuschia}component filetype:#{@cX.off} << #{@opt.fns} >> - is not a processed filetype, (it may be used as a component of a .ssm markup file)\n\trequested #{@opt.cmd} processing skipped\n"
+        puts "\n#{@cX.fuchsia}component filetype:#{@cX.off} << #{@opt.fns} >> - is not a processed filetype, (it may be used as a component of a .ssm markup file)\n\trequested #{@opt.cmd} processing skipped\n"
       else
-        puts "\n#{@cX.fuschia}FILETYPE NOT RECOGNISED:#{@cX.off} << #{@opt.fns} >> - is not a recognized filetype,\n\trequested #{@opt.cmd} processing skipped\n"
+        puts "\n#{@cX.fuchsia}FILETYPE NOT RECOGNISED:#{@cX.off} << #{@opt.fns} >> - is not a recognized filetype,\n\trequested #{@opt.cmd} processing skipped\n"
       end
     end
   end
@@ -596,7 +597,7 @@ module SiSU
             SiSU_Remote::Get.new(@opt,@get_p).sisupod
           end
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@opt,@fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@opt,@fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
           @retry_count +=1
@@ -690,7 +691,7 @@ module SiSU
         elsif action_on_file_ == :true \
         and @opt.files.length == 0
           STDERR.puts %{requested action requires valid sisu markup file [filename (.sst .ssm)] or wildcard (that includes a valid filename)}
-          puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:fuchsia) if @opt.cmd =~/[MV]/
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:fuchsia) if @opt.cmd =~/[MV]/
         end
       elsif @opt.mod.inspect =~/--query/
         require_relative 'sst_identify_markup'          # sst_identify_markup.rb
