@@ -176,7 +176,7 @@ module SiSU_Param_Make
         { page_new: page_new, page_break: page_break, page_line: page_line }
       end
       def language
-        l=if @h['language'] && (@h['language']=~/\S{2,}/)
+        if @h['language'] && (@h['language']=~/\S{2,}/)
           ((@h['language'] =~/,/) \
           ? (@h['language'].split(/,\s*/))
           : [ @h['language'] ])
@@ -186,7 +186,7 @@ module SiSU_Param_Make
       def bold
         m=@h['bold']
         i=(m=~/\/i$/)? 'i' : ''
-        z=if m
+        if m
           x=m.gsub(/^\/(.+?)\/i?/,'\1').
             gsub(/\((?:\?:)?/,'(?:')                                         # avoid need to escape use of brackets within regex provided
           rgx='\b(' + x + ')\b'
@@ -198,7 +198,7 @@ module SiSU_Param_Make
       def italics
         m=@h['italics']
         i=((m=~/\/i$/) ? 'i' : '')
-        z=if m
+        if m
           x=m.gsub(/^\/(.+?)\/i?/,'\1').
             gsub(/\((?:\?:)?/,'(?:')                                         # avoid need to escape use of brackets within regex provided
           rgx='\b(' + x + ')\b'
@@ -216,7 +216,7 @@ module SiSU_Param_Make
       end
       def substitute
         m=@h['substitute']
-        z=if m
+        if m
           w=m.scan(/\/(.+?)\/(i?,)\s*'(.+?)'(?:\s+|\s*;\s*|$)/)
           arr_hash=[]
           matches=''
@@ -430,12 +430,10 @@ module SiSU_Param_Make
         {w: w, h: h}
       end
       def home_button_text
-        s=if @h['home_button_text']
+        if @h['home_button_text']
           @h['home_button_text'].split(/\s*;\s*/)
         else nil
         end
-        #l,n=Db[:home_button],'make.home_button_text'
-        #validate_length(s,l,n)
       end
       def home_button_image
         s=nil
@@ -488,7 +486,7 @@ module SiSU_Param_Make
         end
       end
       def footer
-        s=if @h['footer']
+        if @h['footer']
           @h['footer'].split(/\s*;\s*/)
         else nil
         end
