@@ -154,7 +154,7 @@ module SiSU_Po4a
           SiSU_Po4a::Source::Scroll.new(fn,@dal_array_lang_src,@dal_array_lang_translation,@@md_src,@@md_trn,wrap_width).songsheet
         end
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
