@@ -94,7 +94,7 @@ module SiSU_Sitemaps
           SiSU_Screen::Ansi.new(@opt.cmd,"sitemap index:","#{@env.path.output}/#{@sitemap_idx_fn}").result unless @opt.cmd =~/q/
         end
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
