@@ -98,7 +98,7 @@ module SiSU_TeX
           Dir.mkdir(@env.processing_path.tex) unless FileTest.directory?(@env.processing_path.tex)
         end
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -131,7 +131,7 @@ module SiSU_TeX
         SiSU_TeX::Source::LaTeXtoPdf.new(@md,@particulars.env).latexrun_selective
         Dir.chdir(pwd)
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -209,7 +209,7 @@ module SiSU_TeX
             FileUtils::cp(portrait_pdf,"#{@md.file.output_path.pdf.dir}/#{pdf_p}")
             FileUtils::rm(portrait_pdf)
           else
-            STDERR.puts "#{cX.fuschia}pdf file not generated#{cX.off} <#{cX.blue}#{portrait_pdf.gsub(/.+?([^\/]+?\.pdf)$/,'\1')}#{cX.off}> (check texlive dependencies)"
+            STDERR.puts "#{cX.fuchsia}pdf file not generated#{cX.off} <#{cX.blue}#{portrait_pdf.gsub(/.+?([^\/]+?\.pdf)$/,'\1')}#{cX.off}> (check texlive dependencies)"
             STDERR.puts "#{__FILE__}:#{__LINE__} NOT FOUND: #{portrait_pdf}" if @md.opt.cmd.inspect =~/M/
           end
         end
@@ -218,7 +218,7 @@ module SiSU_TeX
             FileUtils::cp(landscape_pdf,"#{@md.file.output_path.pdf.dir}/#{pdf_l}")
             FileUtils::rm(landscape_pdf)
           else
-            STDERR.puts "#{cX.fuschia}pdf file not generated#{cX.off} <#{cX.blue}#{landscape_pdf.gsub(/.+?([^\/]+?\.pdf)$/,'\1')}#{cX.off}> (check texlive dependencies)"
+            STDERR.puts "#{cX.fuchsia}pdf file not generated#{cX.off} <#{cX.blue}#{landscape_pdf.gsub(/.+?([^\/]+?\.pdf)$/,'\1')}#{cX.off}> (check texlive dependencies)"
             STDERR.puts "#{__FILE__}:#{__LINE__} NOT FOUND: #{landscape_pdf}" if @md.opt.cmd.inspect =~/M/
           end
         end
@@ -246,8 +246,7 @@ module SiSU_TeX
                         and File.size(texfile) > 0
                           #@tex_f_no+=1
                         else
-                          puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:fuchsia)
-                          puts "\tzero file size #{@env.processing_path.tex}/#{texfile}"
+                          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).mark("\tzero file size #{@env.processing_path.tex}/#{texfile}")
                         end
                       end
                     end
@@ -297,7 +296,7 @@ module SiSU_TeX
           lst=Dir["*.{aux,log,out}"]
           lst.each {|file| File.unlink(file)} if lst
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -342,8 +341,7 @@ module SiSU_TeX
           elsif @md.opt.act[:pdf_p][:set]==:on
             'pdfTex portrait'
           else
-            puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:fuchsia)
-            'error: neither landscape nor portrait'
+            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).mark('error: neither landscape nor portrait')
           end
           SiSU_Screen::Ansi.new(@md.opt.cmd,txt_gen).txt_grey if @md.opt.cmd=~/[MVvz]/
           if defined? @md.rights.all \
@@ -372,7 +370,7 @@ module SiSU_TeX
           data=markup(data)
           output(data)
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
