@@ -151,7 +151,7 @@ WOK
       brick(@port,get)
     rescue
       require_relative 'sysenv'                             # sysenv.rb
-      SiSU_Errors::InfoError.new($!,$@,'-W',nil).error do #fix
+      SiSU_Errors::Rescued.new($!,$@,'-W',nil).location do #fix
         __LINE__.to_s + ':' + __FILE__
       end
     ensure
@@ -176,7 +176,7 @@ WOK
         trap("INT"){ s.shutdown }
         s.start
       rescue
-        SiSU_Errors::InfoError.new($!,$@,'-W',nil).error do #fix
+        SiSU_Errors::Rescued.new($!,$@,'-W',nil).location do #fix
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
