@@ -76,7 +76,7 @@ module SiSU_XML_Scaffold
         @md,@dal_array=@particulars.md,@particulars.dal_array
         SiSU_XML_Scaffold::Source::Scroll.new(@dal_array,@md).songsheet
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
