@@ -62,7 +62,22 @@
 =end
 #Ax,Xx,Mx,Rx,Hx,Dx,Px,Ep,Db,Gt,Tex=Array.new(11){{}}
 YEAR='2013'
-Sfx={ txt: '.txt', html: '.html', xhtml: '.xhtml', xml: '.xml', epub: '.epub', epub_xhtml: '.xhtml', odt: '.odt', pdf: '.pdf'}
+Sfx={
+  txt: '.txt',
+  html: '.html',
+  xhtml: '.xhtml',
+  xml: '.xml',
+  xml_sax: '.sax.xml',
+  xml_dom: '.dom.xml',
+  epub: '.epub',
+  epub_xhtml: '.xhtml',
+  odt: '.odt',
+  pdf: '.pdf',
+  manpage: '.1',
+  info: '.info',
+  texinfo: '.texinfo',
+  sql: '.sql.db',
+}
 Ax={
   tab:                       "\t",
 }
@@ -295,13 +310,7 @@ DEVELOPER={
   maintenance:               :false,
 }
 __END__
-puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:red).set
-puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:green)
-puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:fuchsia)
-puts ANSI_C[:red] + __LINE__.to_s + ANSI_C[:off] + ' ' + __FILE__
-puts "#{ANSI_C[:red]} #{__LINE__.to_s} #{ANSI_C[:off]} #{__FILE__}"
-puts ANSI_C[:fuchsia] + __LINE__.to_s + ANSI_C[:off] + ' ' + __FILE__.gsub(/([^\/]+$)/,"#{ANSI_C[:fuchsia]}\\1#{ANSI_C[:off]}")
-puts ANSI_C[:red] + __LINE__.to_s + ANSI_C[:off] + ' ' + __FILE__.gsub(/([^\/]+$)/,"#{ANSI_C[:red]}\\1#{ANSI_C[:off]}")
+utils.rb
 consider:
   〔comment〕
   〔links?????〕
