@@ -449,8 +449,8 @@ WOK
     margin-left: 0em;
     margin-right: 2em;
     text-indent: 0mm;
-    margin-top: 4px;
-    margin-bottom: 4px;
+    margin-top: 0.8em;
+    margin-bottom: 0.8em;
   }
 
   /* indent */
