@@ -423,6 +423,33 @@ module SiSU_DAL_DocumentStructure
       self
     end
   end
+  class ObjectFlag
+    attr_accessor :obj,:is,:of,:flag,:mod,:tmp
+    def initialize
+      @of=:flag
+      @is=@obj=@flag=@mod=@tmp=nil
+    end
+    def flag(h,o=nil)
+      of=     @of                                                              #String, classification - group
+      is=     :flag                                                            #String, classification - specific type
+      obj=    nil                                                              #String, text content
+      flag=   h[:flag]     || ((defined? o.flag)      ? o.flag    : nil)       #String, text content
+      mod=    h[:mod]      || ((defined? o.mod)       ? o.mod     : nil)       #String, text content
+      tmp=    h[:flag]     || ((defined? o.tmp)       ? o.tmp     : nil)       #available for processing, empty after use
+      @of,@is,@obj,@flag,@mod,@tmp=of,is,obj,flag,mod,tmp
+      self
+    end
+    def flag_ocn(h,o=nil)
+      of=     @of                                                              #String, classification - group
+      is=     :flag_ocn                                                        #String, classification - specific type
+      obj=    nil                                                              #String, text content
+      flag=   h[:flag]     || ((defined? o.flag)      ? o.flag    : nil)       #String, text content
+      mod=    h[:mod]      || ((defined? o.mod)       ? o.mod     : nil)       #String, text content
+      tmp=    h[:flag]     || ((defined? o.tmp)       ? o.tmp     : nil)       #available for processing, empty after use
+      @of,@is,@obj,@flag,@mod,@tmp=of,is,obj,flag,mod,tmp
+      self
+    end
+  end
   class ObjectLayout
     attr_accessor :obj,:is,:of,:from,:tmp
     def initialize
