@@ -84,13 +84,11 @@ module SiSU_DAL_BookIndex
           @seg=dob.name
         end
         if defined? dob.idx \
-        and dob.idx.is_a?(String) \
-        and not dob.idx.empty?
-          idx_array << "#{dob.idx}~#{dob.ocn}~#{@seg}"
+        and dob.idx.is_a?(Hash)
+          idx_array << {idx: dob.idx, ocn: dob.ocn, seg: @seg }
         end
         tuned_file << dob if dob
       end
-      idx_array=construct_idx_array(idx_array) if idx_array.length > 0
       if idx_array.length > 0
         the_idx=construct_book_index(idx_array)
         sisu_markup_idx_rel,sisu_markup_idx_rel_html_seg,html_idx,xhtml_idx=nil,nil,nil,nil
@@ -101,61 +99,28 @@ module SiSU_DAL_BookIndex
       end
       [tuned_file,sisu_markup_idx_rel,sisu_markup_idx_rel_html_seg,html_idx,xhtml_idx]
     end
-    def construct_idx_array(idx_array)
-      idx_lst=[]
-      idx_array.each do |idx|
-        idx_list,ocn,seg=@rgx_idx_ocn_seg.match(idx)[1..3]
-        idx_lst <<=if idx_list =~/;/
-          g=idx_list.scan(/[^;]+/)
-          idxl=[]
-          g.each do |i|
-            i=i.strip
-            idxl << { rough_idx: i, ocn: ocn, seg: seg }
-          end
-          idxl
-        else { rough_idx: idx_list, ocn: ocn, seg: seg }
-        end
-      end
-      idx_lst=idx_lst.flatten
-    end
     def construct_book_index(idx_array)
       the_idx={}
       idx_array.each do |idx|
-        if idx[:rough_idx] =~/[|]/ \
-        && idx[:rough_idx] !~/[:]/
-          if @md.opt.cmd =~/[MVv]/
-            p 'book index error? --> ' + idx[:rough_idx]
-          end
-        else
-          idx_lst=idx[:rough_idx].scan(/[^|:]+/)
-          idx_lst[0]=idx_lst[0].strip
-          if idx_lst[0] =~/.+?\+\d+/
-            use=/(.+?)\+(?:\d+)/.match(idx_lst[0])[1]
-          else use=idx_lst[0]
-          end
-          use=use[0].chr.capitalize + use[1,use.length]
-          the_idx[use]={} unless the_idx[use] and defined? the_idx[use]
-          idx_lst.each do |i|
-            i=i.strip
-            i,r=/(.+?)\+(\d+)/.match(i)[1,2] if i =~/.+?\+\d+/
-            x=if idx_lst.length==1 or idx_lst[0].gsub(/\+\d+/,'')==i
-              the_idx[use]['term_node_lev1']=[] unless the_idx[use]['term_node_lev1'] and defined? the_idx[use]['term_node_lev1']
-              x=if r
-                the_idx[use]['term_node_lev1'] << { ocn: idx[:ocn], range: "#{idx[:ocn]}-#{idx[:ocn].to_i+r.to_i}", seg: idx[:seg] }
-                "#{i} #{idx[:ocn]}-#{idx[:ocn].to_i+r.to_i}"
-              else
-                the_idx[use]['term_node_lev1'] << { ocn: idx[:ocn], seg: idx[:seg] }
-                "#{i} #{idx[:ocn]}"
-              end
-            else
-              the_idx[use]['term_node_lev2']={} unless the_idx[use]['term_node_lev2'] and defined? the_idx[use]['term_node_lev2']
-              the_idx[use]['term_node_lev2'][i]=[] unless the_idx[use]['term_node_lev2'][i] and defined? the_idx[use]['term_node_lev2'][i]
-              x=if r
-                the_idx[use]['term_node_lev2'][i] << { ocn: idx[:ocn], range: "#{idx[:ocn]}-#{idx[:ocn].to_i+r.to_i}", seg: idx[:seg] }
-                "#{idx_lst[0]}:#{i} #{idx[:ocn]}-#{idx[:ocn].to_i+r.to_i}"
-              else
-                the_idx[use]['term_node_lev2'][i] << { ocn: idx[:ocn], seg: idx[:seg] }
-                "#{idx_lst[0]}:#{i} #{idx[:ocn]}"
+        idx[:idx].each_pair do |term,term_info|
+          location=(term_info[:plus].to_i > 0) \
+          ? (%{#{idx[:ocn]}-#{idx[:ocn].to_i + term_info[:plus].to_i}})
+          : idx[:ocn].to_s
+          the_idx[term]={} unless the_idx[term] and defined? the_idx[term]
+          the_idx[term]['node_0_terms']=[] unless the_idx[term]['node_0_terms'] and defined? the_idx[term]['node_0_terms']
+          the_idx[term]['node_0_terms'] << { ocn: idx[:ocn], range: location, seg: idx[:seg] }
+          if term_info[:sub].is_a?(Array) \
+          and term_info[:sub].length > 0
+            term_info[:sub].each do |y|
+              y.each_pair do |subterm,subterm_info|
+                location=(subterm_info[:plus].to_i > 0) \
+                ? (%{#{idx[:ocn]}-#{idx[:ocn].to_i + subterm_info[:plus].to_i}})
+                : idx[:ocn].to_s
+                the_idx[term]={} unless the_idx[term] and defined? the_idx[term]
+                the_idx[term]['node_0_terms']=[] unless the_idx[term]['node_0_terms'] and defined? the_idx[term]['node_0_terms']
+                the_idx[term]['node_1_subterms']={} unless the_idx[term]['node_1_subterms'] and defined? the_idx[term]['node_1_subterms']
+                the_idx[term]['node_1_subterms'][subterm]=[] unless the_idx[term]['node_1_subterms'][subterm] and defined? the_idx[term]['node_1_subterms'][subterm]
+                the_idx[term]['node_1_subterms'][subterm] << { ocn: idx[:ocn], range: location, seg: idx[:seg] }
               end
             end
           end
@@ -230,8 +195,8 @@ module SiSU_DAL_BookIndex
             p 'array error? -->'
             print x
           elsif x.is_a?(Hash)
-            if x['term_node_lev1'].is_a?(Array)
-              x['term_node_lev1'].each do |a|
+            if x['node_0_terms'].is_a?(Array)
+              x['node_0_terms'].each do |a|
                 if a[:range]
                   idx[:sst_rel_html_seg][@o]=idx[:sst_rel_html_seg][@o] + %{#{Mx[:lnk_o]}#{a[:range]}#{Mx[:lnk_c]}#{Mx[:rel_o]}/#{a[:seg]}.html##{a[:ocn]}#{Mx[:rel_c]}, }
                   idx[:sst_rel][@t]=idx[:sst_rel][@t] + %{#{Mx[:lnk_o]}#{a[:range]}#{Mx[:lnk_c]}#{Mx[:rel_o]}#{a[:ocn]}#{Mx[:rel_c]}, }
@@ -250,11 +215,9 @@ module SiSU_DAL_BookIndex
               idx[:html][@q]=idx[:html][@q] + '</p>'
               idx[:xhtml][@r]=idx[:xhtml][@r] + '</p>'
             end
-            if x['term_node_lev2']
-              m=x['term_node_lev2']
-              m=m.sort
-              m.each do |k,y|
-                if k !~/term_node_lev1/
+            if x['node_1_subterms']
+             x['node_1_subterms'].sort.each do |k,y|
+                if k !~/node_0_terms/
                   idx[:sst_rel_html_seg][@o]=idx[:sst_rel_html_seg][@o] + %{#{k}, }
                   idx[:sst_rel][@t]=idx[:sst_rel][@t] + %{#{k}, }
                   idx[:html][@q]=idx[:html][@q] + %{\n<p class="book_index_lev2">#{k}, }
@@ -298,8 +261,8 @@ module SiSU_DAL_BookIndex
             p 'array error? -->'
             print x
           elsif x.is_a?(Hash)
-            if x['term_node_lev1'].is_a?(Array)
-              x['term_node_lev1'].each do |a|
+            if x['node_0_terms'].is_a?(Array)
+              x['node_0_terms'].each do |a|
                 if a[:range]
                   print a[:range] + ', '
                 elsif a[:ocn]
@@ -308,11 +271,9 @@ module SiSU_DAL_BookIndex
                 end
               end
             end
-            if x['term_node_lev2']
-              m=x['term_node_lev2']
-              m=m.sort
-              m.each do |k,y|
-                if k !~/term_node_lev1/
+            if x['node_1_subterms']
+              x['node_1_subterms'].sort.each do |k,y|
+                if k !~/node_0_terms/
                   print "\n\t" + k + ', '
                   y.each do |z|
                     if z[:range]
