@@ -171,7 +171,7 @@ module SiSU_DbImport
           STDERR.puts "Error code: #{e.err}"
           STDERR.puts "Error message: #{e.errstr}"
           STDERR.puts "Error SQLSTATE: #{e.state}"
-          SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
           sqlfn="#{@env.processing_path.sql}/#{@md.fnb}.sql"
@@ -184,7 +184,7 @@ module SiSU_DbImport
             puts "#{__FILE__}:#{__LINE__}"
           end
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
           sqlfn="#{@env.processing_path.sql}/#{@md.fnb}.sql"
@@ -209,6 +209,26 @@ module SiSU_DbImport
     end
     def pf_db_import_transaction_close
     end
+    def book_idx_hash_to_str(book_idx)
+      book_idx=book_idx ? book_idx : ''
+      book_idx_str,book_subidx_part='',''
+      if not book_idx.empty?
+        book_idx_str=''
+        book_idx.each_pair do |k0,v0|
+          book_idx_str << %{#{k0}+#{v0[:plus]}}
+          book_subidx_part=''
+          if v0[:sub].length > 0
+            v0[:sub].each do |subterms|
+               subterms.each_pair do |k1,v1|
+                 book_subidx_part << %{\n  #{k1}+#{v1[:plus]} | }
+               end
+            end
+            book_idx_str=book_idx_str + ':' + book_subidx_part
+          end
+        end
+      end
+      book_idx_str
+    end
     def db_import_metadata                                                       #% import documents - populate database
       print %{ #{@cX.grey}import documents dbi_unit #{@cX.off} } if @opt.cmd =~/vVM/
       @tp={}
@@ -285,7 +305,7 @@ module SiSU_DbImport
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
               @col[:plaintext]=clean_searchable_text(plaintext)
-              book_idx=data.idx ? data.idx : ''
+              book_idx=book_idx_hash_to_str(data.idx)
               @col[:book_idx]=clean_searchable_text(book_idx)
               if @en[0] then @en_a,@en_z=@en[0].first,@en[0].last
               end
@@ -321,7 +341,7 @@ module SiSU_DbImport
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
               @col[:plaintext]=clean_searchable_text(plaintext)
-              book_idx=data.idx ? data.idx : ''
+              book_idx=book_idx_hash_to_str(data.idx)
               @col[:book_idx]=clean_searchable_text(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
@@ -353,7 +373,7 @@ module SiSU_DbImport
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
               @col[:plaintext]=clean_searchable_text(plaintext)
-              book_idx=data.idx ? data.idx : ''
+              book_idx=book_idx_hash_to_str(data.idx)
               @col[:book_idx]=clean_searchable_text(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
@@ -383,7 +403,7 @@ module SiSU_DbImport
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
               @col[:plaintext]=clean_searchable_text(plaintext)
-              book_idx=data.idx ? data.idx : ''
+              book_idx=book_idx_hash_to_str(data.idx)
               @col[:book_idx]=clean_searchable_text(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
@@ -441,7 +461,7 @@ module SiSU_DbImport
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
               @col[:plaintext]=clean_searchable_text(plaintext)
-              book_idx=data.idx ? data.idx : ''
+              book_idx=book_idx_hash_to_str(data.idx)
               @col[:book_idx]=clean_searchable_text(book_idx)
               t=SiSU_DbTuple::LoadDocuments.new(@conn,@col,@opt,@file_maint)
               @tuple_array << t.tuple
@@ -569,7 +589,7 @@ module SiSU_DbImport
           end
         end
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -643,8 +663,8 @@ module SiSU_DbImport
         if FileTest.file?("#{@md.file.output_path.txt.dir}/#{@md.file.base_filename.txt}")==true
           f[:txt],u[:txt]='plaintext,', "'#{@md.file.output_path.txt.url}/#{@md.file.base_filename.txt}',"
         end
-        if FileTest.file?("#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_seg}")==true
-          f[:html_toc],u[:html_toc]='html_toc,', "'#{@md.file.output_path.html_seg.url}/#{@md.file.base_filename.html_seg}',"
+        if FileTest.file?("#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}")==true
+          f[:html_toc],u[:html_toc]='html_toc,', "'#{@md.file.output_path.html_seg.url}/#{@md.file.base_filename.html_segtoc}',"
         end
         if FileTest.file?("#{@md.file.output_path.html_scroll.dir}/#{@md.file.base_filename.html_scroll}")==true
           f[:html_doc],u[:html_doc]='html_doc,', "'#{@md.file.output_path.html_scroll.url}/#{@md.file.base_filename.html_scroll}',"
@@ -702,7 +722,7 @@ module SiSU_DbImport
         t=SiSU_DbTuple::LoadUrls.new(@conn,f,u,@@id_t,@opt,@file_maint)
         tuple=t.tuple
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
