@@ -133,7 +133,7 @@ manually create the database: "#{cX.green}#{@db.db}#{cX.off}" if it does not yet
       begin
         SiSU_DbDBI::Case.new(@opt,@conn,@sql_type).cases
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@cf,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@cf,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
