@@ -87,7 +87,7 @@ module SiSU_DigestView
         end
         SiSU_DigestView::Source::Scroll.new(@particulars).songsheet
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
