@@ -107,7 +107,7 @@ module SiSU_EPUB
         SiSU_EPUB::Source::Seg.new(@md,data).songsheet
         SiSU_EPUB::Source::Output.new(@md).songsheet
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -338,7 +338,7 @@ module SiSU_EPUB
                 @@toc[:seg] << toc[:seg]
                 @@toc[:scr] << toc[:seg]
               rescue
-                SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+                SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
                   __LINE__.to_s + ':' + __FILE__
                 end
               end
@@ -635,7 +635,7 @@ module SiSU_EPUB
           end
           out.close
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -650,7 +650,7 @@ module SiSU_EPUB
           end
           out.close
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -724,7 +724,7 @@ WOK
             filename_xhtml.close
           end
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -742,7 +742,7 @@ WOK
             filename_xhtml.close
           end
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
