@@ -171,8 +171,8 @@ module SiSU_EPUB_Format
     margin-left: 0em;
     margin-right: 2em;
     text-indent: 0mm;
-    margin-top: 4px;
-    margin-bottom: 4px;
+    margin-top: 0.8em;
+    margin-bottom: 0.8em;
   }
   p.norm { }
   p.i1 {padding-left: 1em;}
