@@ -144,7 +144,7 @@ WOK
         SiSU_EPUB_Seg::Seg.new.cleanup # (((( added ))))
         #### (((( END )))) ####
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
