@@ -75,7 +75,7 @@ module SiSU_Git
       end
       if @env.output_dir_structure.multilingual?
         m=/((.+?)(?:\~\w{2,3})?)\.((?:-|ssm\.)?sst|ssm)$/ #watch added match for sss
-        fnn,fnb,fnt=@opt.fns[m,1],@opt.fns[m,2],@opt.fns[m,3]
+        fnb,fnt=@opt.fns[m,2],@opt.fns[m,3]
       else m=/(.+?)\.((?:-|ssm\.)?sst|ssm)$/
         fnb=@fnn=@opt.fns[m,1]
         fnt=@opt.fns[m,2]
@@ -189,7 +189,7 @@ module SiSU_Git
       end
       def locate_parse_file
         composite_src=@opt.fns=~/\.ssm$/ ? true : false
-        parse_file=if composite_src \
+        if composite_src \
         and @opt.cmd.inspect !~/m/
           ##SiSU_Assemble::Composite.new(@opt).read
           #SiSU_DAL::Source.new(@opt).read                                         # -m
