@@ -364,12 +364,13 @@ WOK
               @output[lng][:html_mnt] << x
             end
             @output[lng][:html] << x
+            lang_code_insert=SiSU_Env::FilenameLanguageCodeInsert.new(@opt,lng).language_code_insert
             works=[]
             a[1][:md].each do |i|
               manifest_at=if @env.output_dir_structure.by? == :language
-                i[:file] + '.html'
+                i[:file] + Sfx[:html]
               elsif @env.output_dir_structure.by? == :filetype
-                i[:file] + '.' + lng +  '.html'
+                i[:file] + '.' + lang_code_insert + Sfx[:html]
               elsif @env.output_dir_structure.by? == :filename
                 "./#{i[:file]}/#{i[:page]}"
               else '' #error
