@@ -176,7 +176,7 @@ module SiSU_HTML_Seg
         SiSU_HTML_Seg::Seg.new.cleanup # (((( added ))))
         #### (((( END )))) ####
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -273,7 +273,11 @@ module SiSU_HTML_Seg
                   FileUtils::mkdir_p(@file.output_path.html_seg.dir) if File.writable?("#{@file.output_path.base.dir}/.")
                 end
                 SiSU_HTML_Seg::Seg.new(@md).tail
-                segfilename="#{@file.output_path.html_seg.dir}/#{@@seg_name_html[tracking-1]}#{@md.lang_code_insert}#{Sfx[:html]}"
+                fnh={
+                  fn: @@seg_name_html[tracking-1],
+                }
+                fn=@md.file.base_filename.html_seg(fnh)
+                segfilename="#{@file.output_path.html_seg.dir}/#{fn}"
                 output_seg_file=File.new(segfilename,'w') if @@seg_name_html[tracking-1]
                 minitoc=(@make.build.html_minitoc?) \
                 ? @minitoc
@@ -298,7 +302,11 @@ module SiSU_HTML_Seg
                 head(dob)
                #keep use for last segment, eg if metadata is last segment
                if @@seg_name_html[tracking] =='metadata' # this is for metadata
-                 segfilename="#{@file.output_path.html_seg.dir}/#{@@seg_name_html[tracking]}#{@md.lang_code_insert}#{Sfx[:html]}"
+                 fnh={
+                   fn: @@seg_name_html[tracking],
+                 }
+                 fn=@md.file.base_filename.html_seg(fnh)
+                 segfilename="#{@file.output_path.html_seg.dir}/#{fn}"
                  output_seg_file=File.new(segfilename,'w')
                  SiSU_HTML_Seg::Output.new(@md,output_seg_file,@@seg,minitoc,'metadata').output
                  Seg.new.reinitialise
