@@ -96,7 +96,7 @@ module SiSU_Manifest
         data=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
         SiSU_Manifest::Source::Output.new(@md).check_output(data)
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -176,27 +176,29 @@ module SiSU_Manifest
         mp,mn,mt,mr=nil,nil,nil,nil
         ln=SiSU_i18n::Languages.new.language.list
         Px[:lng_lst].each do |lc|
+          lngc=SiSU_Env::FilenameLanguageCodeInsert.new(@md.opt,lc).language_code_insert
+          fnh={
+             fn: @md.fnb,
+             lng: lngc,
+          }
+          mn=@f.base_filename.manifest(fnh)
           if @o_str.dump_or_redirect? #does not work for --redirect or --dump
             mp="#{@f.output_path.base.dir}"
-            mn="#{@md.fnb}.html"
             mt="#{mp}/#{mn}"
             mr="../../#{lc}/manifest/#{mn}"
             mu="#{url}/#{mn}"
           elsif @f.output_dir_structure.by_language_code?
             mp="#{@f.output_path.base.dir}/#{lc}/manifest"
-            mn="#{@md.fnb}.html"
             mt="#{mp}/#{mn}"
             mr="../../#{lc}/manifest/#{mn}"
             mu="#{url}/#{lc}/manifest/#{mn}"
           elsif @f.output_dir_structure.by_filetype?
             mp="#{@f.output_path.base.dir}/manifest"
-            mn="#{@md.fnb}.#{lc}.html"
             mt="#{mp}/#{mn}"
             mr=mn
             mu="#{url}/manifest/#{mn}"
           else
             mp="#{@f.output_path.base.dir}/#{@md.fnb}"
-            mn="sisu_manifest.#{lc}.html"
             mt="#{mp}/#{mn}"
             mr=mn
             mu="#{url}/#{mn}"
@@ -211,18 +213,16 @@ module SiSU_Manifest
         @m=@m.uniq
       end
       def languages(id,file)
-        flv=published_manifests?
         @manifest[:html] << %{<tr><th class="left"><div id="horizontal_links"><ul id="horizontal">\n}
-        flv.each do |l|
+        published_manifests?.each do |l|
           SiSU_Translate::Source.new(@md,@language,l[:n]).language_list
           @manifest[:txt] << "#{l[:mu]} #{l[:l]}\n"
           @manifest[:html] << %{<li class="norm"><a href="#{l[:rel]}">#{l[:l]}</a>&nbsp;&nbsp;&nbsp;</li>}
         end
         @manifest[:html] << %{</ul></div></th></tr>\n}
       end
-      def published_languages(id,file)
-        flv=published_manifests?
-        flv.each do |l|
+      def published_languages(id)
+        published_manifests?.each do |l|
           @manifest[:txt] << "#{l[:mu]} #{l[:l]}\n"
           @manifest[:html] << %{<tr><th class="left"><p class="bold"><a href="#{l[:mu]}">#{l[:l]}</a></p></th><td><p class="norm">#{l[:l]}</p><p class="tiny">#{@brace_url.xml_open}<a href="#{l[:mu]}">#{l[:mu]}</a>#{@brace_url.xml_close}</p></td><td class="right"><p class="right">&nbsp;</p></td></tr>\n}
         end
@@ -445,8 +445,8 @@ module SiSU_Manifest
       end
       def language_versions
         if FileTest.file?(@f.place_file.manifest.dir)==true
-          id,file='Markup (SiSU source)',@md.fns
-          published_languages(id,file)
+          id='Markup (SiSU source)'
+          published_languages(id)
         end
       end
       def qrc_image
@@ -841,10 +841,11 @@ WOK
             '..'
           else '..'
           end
+          output_organised_by="(output organised by #{@env.output_dir_structure.by?})"
           harvest=(FileTest.file?("#{pth_local}/authors#{@fn_lng}.html") \
           && FileTest.file?("#{pth_local}/topics#{@fn_lng}.html")) \
-          ? %{<p class="small"><a href="#{pth_rel_home}/index.html">.:</a> other document manifests: [<a href="#{pth_rel}/authors#{@fn_lng}.html">authors</a>] [<a href="#{pth_rel}/topics#{@fn_lng}.html">topics</a>]</p>}
-          : ''
+          ? %{<p class="small"><a href="#{pth_rel_home}/index.html">.:</a> other document manifests: [<a href="#{pth_rel}/authors#{@fn_lng}.html">authors</a>] [<a href="#{pth_rel}/topics#{@fn_lng}.html">topics</a>] #{output_organised_by}</p>}
+          : %{<p class="small"><a href="#{pth_rel_home}/index.html">#{output_organised_by}</p>}
           manifest_title=%{<p class="bold">#{@translate.manifest_description}</p>#{harvest}}
           @manifest[:html] <<<<WOK
 <div id="horizontal_links">
@@ -917,7 +918,7 @@ WOK
 WOK
           output
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
