@@ -654,12 +654,11 @@ module SiSU_XML_Tags #Format
       @vz=SiSU_Viz::Defaults.new
     end
     def meta_content_clean(content='')
-      content
-      unless content.nil?
+      content=if not content.nil?
         content=content.tr('"',"'")
         content=SiSU_XML_Munge::Trans.new(@md).char_enc.utf8(content)
+      else content
       end
-      content
     end
     def rdfseg #segHead
       rdftoc
@@ -693,7 +692,7 @@ WOK
      * SiSU http://www.jus.uio.no/sisu
 -->
 WOK
-     end
+      end
     end
     def comment_xml_sax
       desc='SiSU XML, SAX type representation'
