@@ -99,7 +99,7 @@ module SiSU_SimpleXML_ModelSax
         end
         SiSU_SimpleXML_ModelSax::Convert::Songsheet.new(@fns_array,@particulars).songsheet
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure #file closed in songsheet
@@ -123,7 +123,7 @@ module SiSU_SimpleXML_ModelSax
           SiSU_SimpleXML_ModelSax::Convert::Tidy.new(@md,@env).xml if @md.opt.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@md.fn[:sxs]).xml if @md.opt.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
