@@ -106,11 +106,10 @@ module SiSU_TexInfo
         tool=(@opt.cmd =~/[MVv]/) \
         ?  "#{@env.program.texinfo} #{@md.file.output_path.texinfo.dir}/#{@md.file.base_filename.info}"
         : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
-        tell=@opt.cmd=~/[MVvz]/ \
+        @opt.cmd=~/[MVvz]/ \
         && @opt.cmd !~/q/ \
         ? SiSU_Screen::Ansi.new(@opt.cmd,'TexInfo',tool).green_hi_blue
         : SiSU_Screen::Ansi.new(@opt.cmd,'TexInfo',tool).green_title_hi
-        tell
         @md=SiSU_Param::Parameters.new(@opt).get
         directories
         @marshalfile=SiSU_Env::InfoFile.new(@opt.fns).marshal.dal_content
@@ -260,7 +259,6 @@ module SiSU_TexInfo
       @tex_file=[]
       @row_break='\\\\\\'
       @break_page="#{@row_break}\n#{@row_break} \n"
-      md={}
       @tex_file << SiSU_TexInfoFormat::Texinfo.new(@md).head
       mono=SiSU_TexInfoFormat::Texinfo.new(@md)
       @tex_file << mono.topnode(@md.title.full)
@@ -352,10 +350,6 @@ module SiSU_TexInfo
     def number_titles
       data,data_new=@data,[]
       @tex_file=[]
-      input=%{#{@md.markup}}[/(num_top\s*=\s*(\d?))?/m,2] # else default usually 4  # this was a bit of a trick required to pass nil to input if nothing matched... #puts input
-      num_top=input.to_i
-      t_no1=0;  t_no2=0;  t_no3=0;  t_no4=0;
-      no1=num_top; no2=(num_top + 1); no3=(num_top + 2);  no4=(num_top + 3);
       data.each do |dob|
         if (@md.markup =~ /num_top/i) \
         && (dob.obj !~ /#{Rx[:meta]}/)
