@@ -116,7 +116,8 @@ module SiSU_TeX_Pdf
       "\\begin{tiny}\\hspace{0mm}\\end{tiny}{\\marginpar{\\begin{tiny}\\hspace{0mm}\\hypertarget{#{dob.ocn}}{#{show_ocn}}\\end{tiny}}}" #ocn object citation numbering
     end
     def table_special_characters(r)
-      r=r.gsub(/#{Mx[:tc_p]}|$/u,'&').
+      r=r.gsub(/#{Mx[:tc_p]}/mu,'&').
+        gsub(/#{Mx[:tc_c]}/m,'\\\\\\').
         gsub(/%/,'\%').
         gsub(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'\begin{bfseries}\1 \end{bfseries}').
         gsub(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,'\emph{\1}').
