@@ -73,7 +73,7 @@ module SiSU_Urls
       begin
         SiSU_Urls::OutputUrls.new(@opt).songsheet if @opt.fnb
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -126,7 +126,7 @@ module SiSU_Urls
       begin
        @opt.cmd=~/U/ ? urls_all : (urls_select unless @opt.cmd=~/q/)
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
