@@ -88,7 +88,7 @@ module SiSU_Wikispeak
         @dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
         SiSU_Wikispeak::Source::Scroll.new(@dal_array,@md).songsheet
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
