@@ -97,7 +97,7 @@ module SiSU_XHTML
         end
         SiSU_XHTML::Source::Songsheet.new(@particulars).song
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -116,7 +116,7 @@ module SiSU_XHTML
           SiSU_XHTML::Source::Tidy.new(@md,@file.place_file.xhtml.dir).xml if @md.opt.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@file.place_file.xhtml.dir).xml if @md.opt.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
         rescue
-          SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
