@@ -79,7 +79,7 @@ module SiSU_XML_Fictionbook
         @dal_array=SiSU_DAL::Source.new(@opt).get
         SiSU_XML_Fictionbook::Source::Scroll.new(@dal_array,@md).songsheet
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
