@@ -271,7 +271,7 @@ WOK
   end
   class FormatTextObject
     attr_accessor :md,:txt,:format,:paranum,:p_num,:para_id,:headname,:font
-   def initialize(md,dob)
+    def initialize(md,dob)
       @md,@dob=md,dob
       if @dob[:ocn]=~/\d+/
         @paranum=/(\d+)/m.match(@dob[:ocn])[1]
@@ -482,7 +482,7 @@ WOK
 </tr></table>}
     end
     def make_scroll_seg_pdf
-      manifest=scroll=seg=''
+      seg=''
       wgt=Widget.new(@md)
       seg=%{<td align="center" bgcolor=#{@vz.color_band2}>
   #{@vz.nav_txt_toc_link}
@@ -500,7 +500,6 @@ WOK
 </tr></table>}
     end
     def make_concordance
-      manifest=scroll=seg=''
       wgt=Widget.new(@md)
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
@@ -751,7 +750,6 @@ WOK
 #{@vz.table_close}}
     end
     def toc_next2
-      pre,nxt=false,true
       toc_nav(false,true).dup
     end
     def toc_pre_next2
@@ -761,10 +759,9 @@ WOK
       toc_nav(true,false,2).dup
     end
     def doc_types #used in seg_nav_band ###
-      scroll=seg=''
       wgt=Widget.new(@md)
       #dir=SiSU_Env::InfoEnv.new(@md.fns)
-      x=if @md.concord_make
+      if @md.concord_make
         %{
 <table summary="segment navigation available documents types: toc,doc,pdf,concordance" border="0" cellpadding="3" cellspacing="0">
 <tr>
@@ -1005,7 +1002,7 @@ WOK
         end
       else
         if @md.opt.cmd =~/M/
-          p __FILE__ +':'+ __LINE__.to_s
+          p __FILE__ << ':' << __LINE__.to_s
           p t_o.class
           p caller
         end
